Authors
==========
This package is being developed and maintained by `Fraunhofer AICOS <https://www.aicos.fraunhofer.pt/en/home.html>`_.

.. image:: imgs/fhp_logo.png
    :align: center
    :scale: 25 %
    :alt: FhP-AICOS

TSFEL was written in collaboration with `Cognitive Systems Lab of University of Bremen <https://www.uni-bremen.de/csl/>`_.

Lead Development Team
---------------------

- Duarte Folgado (`duarte.folgado@fraunhofer.pt <duarte.folgado@fraunhofer.pt>`_)
- Hugo Gamboa (`hugo.gamboa@fraunhofer.pt <hugo.gamboa@fraunhofer.pt>`_)
- Marília Barandas  (`marilia.barandas@fraunhofer.pt <marilia.barandas@fraunhofer.pt>`_)


Contributors
------------
- Hui Liu
- Isabel Curioso
- Letícia Fernandes
- Mariana Abreu
- Patrícia Bota
- Sara Santos
- Tanja Schultz


Citing TSFEL
--------------
TSFEL was published in Barandas, Marília and Folgado, Duarte, et al. "*TSFEL: Time Series Feature Extraction Library.*" SoftwareX 11 (2020). `https://doi.org/10.1016/j.softx.2020.100456 <https://doi.org/10.1016/j.softx.2020.100456>`_.

If you used TSFEL in your scientific publication, we would very appreciated if you include the adequate citation:


  Bibtex entry::

    @article{barandas2020tsfel,
      title={TSFEL: Time Series Feature Extraction Library},
      author={Barandas, Mar{\'\i}lia and Folgado, Duarte and Fernandes, Let{\'\i}cia and Santos, Sara and Abreu, Mariana and Bota, Patr{\'\i}cia and Liu, Hui and Schultz, Tanja and Gamboa, Hugo},
      journal={SoftwareX},
      volume={11},
      pages={100456},
      year={2020},
      publisher={Elsevier}
    }
